diff --git a/.github/actions/spelling/allow.txt b/.github/actions/spelling/allow.txt
index 00cc67ea0..01994ec78 100644
--- a/.github/actions/spelling/allow.txt
+++ b/.github/actions/spelling/allow.txt
@@ -3,3 +3,7 @@ https
ssh
ubuntu
runcount
+nunit
+velopack
+vpk
+vsc
\ No newline at end of file
diff --git a/.github/actions/spelling/expect.txt b/.github/actions/spelling/expect.txt
index 2d6fdb7f0..48ed17983 100644
--- a/.github/actions/spelling/expect.txt
+++ b/.github/actions/spelling/expect.txt
@@ -106,3 +106,5 @@ alreadyexists
JsonRPC
JsonRPCV2
Softpedia
+ime
+LPWStr
\ No newline at end of file
diff --git a/.github/actions/spelling/patterns.txt b/.github/actions/spelling/patterns.txt
index f29f57ad5..52db82489 100644
--- a/.github/actions/spelling/patterns.txt
+++ b/.github/actions/spelling/patterns.txt
@@ -29,6 +29,12 @@
# IServiceProvider
\bI(?=(?:[A-Z][a-z]{2,})+\b)
+# KListener
+\bK(?=(?:[A-Z][a-z]{2,})+\b)
+
+# TApplication
+\bT(?=(?:[A-Z][a-z]{2,})+\b)
+
# hit-count: 297 file-count: 18
# uuid:
\b[0-9a-fA-F]{8}-(?:[0-9a-fA-F]{4}-){3}[0-9a-fA-F]{12}\b
diff --git a/Flow.Launcher.Core/Configuration/Portable.cs b/Flow.Launcher.Core/Configuration/Portable.cs
index 826e9f8ac..f46701b75 100644
--- a/Flow.Launcher.Core/Configuration/Portable.cs
+++ b/Flow.Launcher.Core/Configuration/Portable.cs
@@ -66,9 +66,9 @@ namespace Flow.Launcher.Core.Configuration
}
- internal void IndicateDeletion(string filePathTodelete)
+ internal void IndicateDeletion(string filePathToDelete)
{
- var deleteFilePath = Path.Combine(filePathTodelete, DataLocation.DeletionIndicatorFile);
+ var deleteFilePath = Path.Combine(filePathToDelete, DataLocation.DeletionIndicatorFile);
using (var _ = File.CreateText(deleteFilePath))
{
}
@@ -80,7 +80,7 @@ namespace Flow.Launcher.Core.Configuration
///
public void PreStartCleanUpAfterPortabilityUpdate()
{
- // check whether the package locate in %localappdata%
+ // check whether the package locate in %LocalAppData%
// if not create the portable data folder
// Don't create the folder if the version is 1.0.0 (Dev) to allow potential debugging with data in the project folder
// It is still possible to create the UserData folder for dev version manually but we want to keep the current behavior
diff --git a/Flow.Launcher.Test/PluginLoadTest.cs b/Flow.Launcher.Test/PluginLoadTest.cs
index 65700ee36..f41c10c18 100644
--- a/Flow.Launcher.Test/PluginLoadTest.cs
+++ b/Flow.Launcher.Test/PluginLoadTest.cs
@@ -65,7 +65,7 @@ namespace Flow.Launcher.Test
}
[Test]
- public void GivenDuplicatePluginMetadatasWithNoUniquePluginWhenLoadedThenShouldReturnEmptyList()
+ public void GivenDuplicatePluginMetaDataWithNoUniquePluginWhenLoadedThenShouldReturnEmptyList()
{
// Given
var duplicateList = new List
diff --git a/Flow.Launcher/App.xaml.cs b/Flow.Launcher/App.xaml.cs
index 2792fdfff..99b575d05 100644
--- a/Flow.Launcher/App.xaml.cs
+++ b/Flow.Launcher/App.xaml.cs
@@ -65,7 +65,7 @@ namespace Flow.Launcher
RegisterAppDomainExceptions();
RegisterDispatcherUnhandledException();
- var imageLoadertask = ImageLoader.InitializeAsync();
+ var imageLoaderTask = ImageLoader.InitializeAsync();
_settingsVM = new SettingWindowViewModel(_updater, _portable);
_settings = _settingsVM.Settings;
@@ -86,7 +86,7 @@ namespace Flow.Launcher
Http.Proxy = _settings.Proxy;
await PluginManager.InitializePluginsAsync(API);
- await imageLoadertask;
+ await imageLoaderTask;
var window = new MainWindow(_settings, _mainVM);
diff --git a/Flow.Launcher/Helper/SingleInstance.cs b/Flow.Launcher/Helper/SingleInstance.cs
index b0b8e84b2..a516bfee0 100644
--- a/Flow.Launcher/Helper/SingleInstance.cs
+++ b/Flow.Launcher/Helper/SingleInstance.cs
@@ -14,7 +14,7 @@ using System.Windows;
using Velopack;
// http://blogs.microsoft.co.il/arik/2010/05/28/wpf-single-instance-application/
-// modified to allow single instace restart
+// modified to allow single instance restart
namespace Flow.Launcher.Helper
{
internal enum WM
@@ -311,9 +311,9 @@ namespace Flow.Launcher.Helper
catch (NotSupportedException)
{
// The application was clickonce deployed
- // Clickonce deployed apps cannot recieve traditional commandline arguments
- // As a workaround commandline arguments can be written to a shared location before
- // the app is launched and the app can obtain its commandline arguments from the
+ // Clickonce deployed apps cannot recieve traditional command line arguments
+ // As a workaround command line arguments can be written to a shared location before
+ // the app is launched and the app can obtain its command line arguments from the
// shared location
string appFolderPath = Path.Combine(
Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData), uniqueApplicationName);
diff --git a/README.md b/README.md
index 9ebbe246c..325dc9e4b 100644
--- a/README.md
+++ b/README.md
@@ -198,7 +198,7 @@ And you can download [early access version](https://github.com/Flow-Launcher/Pre
- Fully portable.
- Type `flow user data` to open your saved user settings folder. They are located at:
- If using roaming: `%APPDATA%\FlowLauncher`
- - If using portable, by default: `%localappdata%\FlowLauncher\app-\UserData`
+ - If using portable, by default: `%LocalAppData%\FlowLauncher\app-\UserData`
- Type `open log location` to open your logs folder, they are saved along with your user settings folder.
### 🎮 Game Mode
diff --git a/Flow.Launcher.Plugin/SharedCommands/FilesFolders.cs b/Flow.Launcher.Plugin/SharedCommands/FilesFolders.cs
index 1341318e0..2fa0a0975 100644
--- a/Flow.Launcher.Plugin/SharedCommands/FilesFolders.cs
+++ b/Flow.Launcher.Plugin/SharedCommands/FilesFolders.cs
@@ -35,7 +35,7 @@ namespace Flow.Launcher.Plugin.SharedCommands
///
/// Copies the folder and all of its files and folders
/// including subfolders to the target location
///
///
///
@@ -64,15 +64,15 @@ namespace Flow.Launcher.Plugin.SharedCommands
FileInfo[] files = dir.GetFiles();
foreach (FileInfo file in files)
{
- string temppath = Path.Combine(targetPath, file.Name);
- file.CopyTo(temppath, false);
+ string tempPath = Path.Combine(targetPath, file.Name);
+ file.CopyTo(tempPath, false);
}
// Recursively copy subdirectories by calling itself on each subdirectory until there are no more to copy
- foreach (DirectoryInfo subdir in dirs)
+ foreach (DirectoryInfo subDir in dirs)
{
- string temppath = Path.Combine(targetPath, subdir.Name);
- CopyAll(subdir.FullName, temppath);
+ string temppath = Path.Combine(targetPath, subDir.Name);
+ CopyAll(subDir.FullName, temppath);
}
}
catch (Exception)
@@ -35,7 +35,7 @@ namespace Flow.Launcher.Plugin.SharedCommands
///
/// Copies the folder and all of its files and folders
- /// including subfolders to the target location
+ /// including subFolders to the target location
///
///